/*
 * AbstractMechanism.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package net.outer_planes.jso.sasl;


import java.util.Collections;
import java.util.Map;
import javax.security.auth.callback.CallbackHandler;

import org.apache.log4j.Logger;

import org.jabberstudio.jso.StreamDataFactory;
import org.jabberstudio.jso.sasl.SASLMechanism;
import org.jabberstudio.jso.util.Utilities;

/**
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.12
 */
public abstract class AbstractMechanism implements SASLMechanism {
    //Fields
    private SASLMechanism.Status    _CurrStatus;
    private String                  _Server;
    private StreamDataFactory       _SDF;
    private CallbackHandler         _CBH;
    private Map                     _Props = new java.util.TreeMap();
    
    //Constructors
    public AbstractMechanism(StreamDataFactory sdf, String srv, CallbackHandler cbh, Map props) {
        _CurrStatus = READY;
        _Server = srv;
        _CBH = cbh;
        _SDF = sdf;
        
        if (props != null)
            _Props.putAll(props);
    }

    //Methods
    protected Logger obtainLogger() {
        return Logger.getLogger(getClass());
    }
    
    public SASLMechanism.Status getCurrentStatus() {
        return _CurrStatus;
    }
    public void setCurrentStatus(SASLMechanism.Status stat) {
        _CurrStatus = stat;
    }
    
    public CallbackHandler getCallbackHandler() {
        return _CBH;
    }
    
    public String getServer() {
        return _Server;
    }
    
    public StreamDataFactory getDataFactory() {
        return _SDF;
    }
    
    public Map getProperties() {
        return Collections.unmodifiableMap(_Props);
    }
    public Object getProperty(String key) {
        if (!Utilities.isValidString(key))
            throw new IllegalArgumentException("key cannot be null or \"\"");
        return _Props.get(key);
    }
    public void setProperty(String key, Object val) {
        if (!Utilities.isValidString(key))
            throw new IllegalArgumentException("key cannot be null or \"\"");
        
        if (val != null)
            _Props.put(key, val);
        else
            _Props.remove(key);
    }
    
    public Status reset() {
        setCurrentStatus(READY);
        
        return getCurrentStatus();
    }
    
    public byte[] wrap(byte[] input) throws IllegalStateException {
        return input;
    }
    public byte[] unwrap(byte[] input) throws IllegalStateException {
        return input;
    }
}