/*
 * PrivacyListNode.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package net.outer_planes.jso.x.core;


import java.util.List;

import org.jabberstudio.jso.StreamDataFactory;
import org.jabberstudio.jso.StreamElement;
import org.jabberstudio.jso.StreamNode;
import org.jabberstudio.jso.StreamObject;
import org.jabberstudio.jso.x.core.PrivacyItem;
import org.jabberstudio.jso.x.core.PrivacyList;

import net.outer_planes.jso.ElementNode;

/**
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.12
 */
public class PrivacyListNode extends ElementNode implements PrivacyList {
    //Constructors
    public PrivacyListNode(StreamDataFactory sdf) {
        super(sdf, NAME);
    }
    protected PrivacyListNode(StreamElement parent, PrivacyListNode base) {
        super(parent, base);
    }

    //Fields
    private int     _HighOrder = 0;

    //Methods
    public String getName() {
        String      name = getAttributeValue(PrivacyQueryNode.ATTRNAME_NAME);

        return ((name != null) ? name : "");
    }
    public void setName(String name) {
        setAttributeValue(PrivacyQueryNode.ATTRNAME_NAME, name);
    }

    public List listItems() {
        return listElements(PrivacyItem.class);
    }
    public PrivacyItem addItem(PrivacyItem.Action act) throws IllegalArgumentException {
        return addItem(act, -1);
    }
    public PrivacyItem addItem(PrivacyItem.Action act, int order) throws IllegalArgumentException {
        PrivacyItemNode     item;

        if (act == null)
            throw new IllegalArgumentException("Action cannot be null");
        if (order < 0)
            order = nextOrder();

        item = (PrivacyItemNode)addElement(PrivacyItemNode.NAME, PrivacyItemNode.class);
        item.setAction(act);
        item.setOrder(order);

        return item;
    }
    public void clearItems() {
        clearElements(PrivacyItem.class);
    }

    public void add(StreamNode node) {
        if (node instanceof PrivacyItem) {
            _HighOrder = Math.max(_HighOrder, ((PrivacyItem)node).getOrder());
        }

        super.add(node);
    }
    
    protected int nextOrder() {
        return ++_HighOrder;
    }

    public StreamObject copy(StreamElement parent) {
        return new PrivacyListNode(parent, this);
    }
}