/*
 * RosterQueryNode.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package net.outer_planes.jso.x.core;


import java.util.Iterator;
import java.util.List;

import org.jabberstudio.jso.JID;
import org.jabberstudio.jso.NSI;
import org.jabberstudio.jso.StreamDataFactory;
import org.jabberstudio.jso.StreamElement;
import org.jabberstudio.jso.StreamObject;
import org.jabberstudio.jso.util.Utilities;
import org.jabberstudio.jso.x.core.RosterExtension;
import org.jabberstudio.jso.x.core.RosterItem;
import org.jabberstudio.jso.x.core.RosterQuery;

import net.outer_planes.jso.ElementNode;
import net.outer_planes.jso.ExtensionNode;

/**
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.8
 */
public class RosterNode extends ExtensionNode implements RosterQuery, RosterExtension {
    //Inner-classes
    public static class Item extends ElementNode implements RosterItem {
        //"Constants"
        public static final NSI     NAME = new NSI("item", null);
        
        public static final NSI     ATTR_JID = new NSI("jid", null);
        public static final NSI     ATTR_NAME = new NSI("name", null);
        public static final NSI     ATTR_SUBSCRIPTION = new NSI("subscription", null);
        public static final NSI     ATTR_ASK = new NSI("ask", null);
        
        //Constructors
        public Item(StreamDataFactory sdf) {
            super(sdf, NAME);
        }
        public Item(StreamDataFactory sdf, NSI name) {
            super(sdf, name);
        }
        public Item(StreamElement parent, Item base) {
            super(parent, base);
        }
        
        //Methods
        public JID getJID() {
            Object      val = getAttributeObject(ATTR_JID);
            JID         jid = null;
            
            if (val instanceof JID)
                jid = (JID)val;
            else if (val != null) {
                try {
                    jid = JID.valueOf(val);
                    setAttributeObject(ATTR_JID, jid);
                } catch (IllegalArgumentException iae) {}
            }
            
            return jid;
        }
        public void setJID(JID jid) throws IllegalArgumentException {
            if (jid == null)
                throw new IllegalArgumentException("JID cannot be null");
            
            setAttributeObject(ATTR_JID, jid);
        }
        
        public String getDisplayName() {
            String  val = getAttributeValue(ATTR_NAME);
            
            return (val != null) ? val : "";
        }
        public void setDisplayName(String name) {
            setAttributeValue(ATTR_NAME, (Utilities.isValidString(name) ? name : null));
        }
        
        public boolean isAskSubscribe() {
            String      val = getAttributeValue(ATTR_ASK);
            
            return Utilities.equateStrings("subscribe", val);
        }
        public void setAskSubscribe(boolean sub) {
            String      val = (sub) ? "subscribe" : null;
            
            setAttributeValue(ATTR_ASK, val);
        }
        
        public boolean isAskUnsubscribe() {
            String      val = getAttributeValue(ATTR_ASK);
            
            return Utilities.equateStrings("unsubscribe", val);
        }
        public void setAskUnsubscribe(boolean unsub) {
            String      val = (unsub) ? "unsubscribe" : null;
            
            setAttributeValue(ATTR_ASK, val);
        }
        
        public SubscriptionType getSubscription() {
            Object              val = getAttributeObject(ATTR_SUBSCRIPTION);
            SubscriptionType    type = NONE;
            
            if          (val instanceof SubscriptionType) {
                type = (SubscriptionType)val;
            } else if   (val != null) {
                String      str = val.toString();
                
                if      (Utilities.equateStrings(TO.toString(), str))
                    type = TO;
                else if (Utilities.equateStrings(FROM.toString(), str))
                    type = FROM;
                else if (Utilities.equateStrings(BOTH.toString(), str))
                    type = BOTH;
                else if (Utilities.equateStrings(REMOVE.toString(), str))
                    type = REMOVE;
                
                if (type != null)
                    setAttributeObject(ATTR_SUBSCRIPTION, type);
            }
            
            return type;
        }
        public void setSubscription(SubscriptionType type) {
            if (type == null)
                type = NONE;
            
            setAttributeObject(ATTR_SUBSCRIPTION, type);
        }
        
        public String[] getGroups() {
            List        grpList = new java.util.LinkedList();
            String[]    grpArr;
            Iterator    grpItr = listElements("group").iterator();
            
            //Retrieve group values
            while (grpItr.hasNext()) {
                StreamElement   grp = (StreamElement)grpItr.next();
                
                grpList.add(grp.normalizeTrimText());
            }
            
            //Format into array
            grpArr = new String[grpList.size()];
            grpArr = (String[])grpList.toArray(grpArr);
            
            return grpArr;
        }
        public void setGroups(String[] grps) {
            NSI             grpName = new NSI("group", null);
            Iterator        prevGrps = listElements(grpName).iterator();
            int             idx;
            
            //Validate groups
            if (grps == null)
                grps = new String[0];
            
            //Remove existing groups
            while (prevGrps.hasNext())
                ((StreamElement)prevGrps.next()).detach();
            
            //Add new groups
            for (idx = 0; idx < grps.length; idx++)
                addElement(grpName).addText(grps[idx]);
        }
        
        protected StreamElement getGroupElement(String grp) {
            Iterator        itr = listElements("group").iterator();
            StreamElement   found = null;
            
            while ((found == null) && itr.hasNext()) {
                found = (StreamElement)itr.next();
                
                if (!Utilities.equateStrings(found.normalizeTrimText(), grp))
                    found = null;
            }
            
            return found;
        }
        public List listGroups() {
            List        grpList = new java.util.LinkedList();
            Iterator    grpItr = listElements("group").iterator();
            
            //Retrieve group values
            while (grpItr.hasNext()) {
                StreamElement   grp = (StreamElement)grpItr.next();
                
                grpList.add(grp.normalizeTrimText());
            }
            
            return grpList;
        }
        public void addGroup(String grp) {
            StreamElement   elem;
            
            if (Utilities.isValidString(grp)) {
                elem = getGroupElement(grp);
                
                if (elem == null)
                    addElement("group").addText(grp);
            }
        }
        public void removeGroup(String grp) {
            StreamElement   elem;
            
            if (Utilities.isValidString(grp)) {
                elem = getGroupElement(grp);
                
                if (elem != null)
                    elem.detach();
            }
        }
        public void clearGroups() {
            clearElements("group");
        }
        
        public StreamObject copy(StreamElement parent) {
            return new Item(parent, this);
        }
    }
    
    //Constructors
    public RosterNode(StreamDataFactory sdf, NSI name) {
        super(sdf, name);
    }
    public RosterNode(StreamElement p, RosterNode base) {
        super(p, base);
    }
    
    //Methods
    public static RosterNode createRosterQuery(StreamDataFactory sdf) {
        return new RosterNode(sdf, new NSI("query", RosterQuery.NAMESPACE));
    }
    public static RosterNode createRosterExtension(StreamDataFactory sdf) {
        return new RosterNode(sdf, new NSI("x", RosterExtension.NAMESPACE));
    }
    
    public RosterItem getItem(JID jid) {
        Iterator        items = listElements(Item.class).iterator();
        RosterItem      item = null;
        
        //Validate JID
        if (jid == null)
            throw new IllegalArgumentException("JID cannot be null");
        
        //Search for matching RosterItem
        while (items.hasNext() && (item == null)) {
            RosterItem  test = (RosterItem)items.next();
            
            if (test.getJID().equals(jid))
                item = test;
        }
        
        return item;
    }
    public RosterItem createItem(JID jid) {
        RosterItem  item = getItem(jid);
        
        if (item == null) {
            Item    nativeItem = new Item(getDataFactory());

            nativeItem.setJID(jid);
            add(nativeItem);
            item = nativeItem;
        }
        
        return item;
    }
    
    public StreamObject copy(StreamElement parent) {
        return new RosterNode(parent, this);
    }
}