/*
 * StreamElementRegistry.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package org.jabberstudio.jso;


import org.jabberstudio.jso.NSI;

/**
 * <p>
 * Interface for registering and unregistering <tt>StreamElementFactory</tt>
 * implementations.</p>
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.10
 */
public interface StreamElementRegistry {
    /**
     * <p>
     * Registers the given <tt>StreamElementFactory</tt> to the given
     * <tt>NSI</tt>. This method will replace any <tt>StreamElementFactory</tt>
     * previously registered for <tt>name</tt> with <tt>sef</tt>.</p>
     *
     * <p>
     * If <tt>xf</tt> is <tt>null</tt> or <tt>ns</tt> is not supported by
     * <tt>xf</tt>, this method does nothing.</p>
     *
     * @param name The <tt>NSI</tt> to register to.
     * @param sef The <tt>ExtensionFactory</tt> to register.
     * @since   JSO-0.10
     */
    public void registerElementFactory(NSI name, StreamElementFactory sef);
    /**
     * <p>
     * Registers the given <tt>StreamElementFactory</tt> to all of its
     * supported <tt>NSI</tt>s.  This method is designed as a convenience
     * to register all of the <tt>NSI</tt>s that a <tt>StreamElementFactory</tt>
     * supports.  Caution should be exercised, as this method will
     * replace any previously registered <tt>StreamElementFactory</tt>
     * objects for all of the <tt>NSI</tt>s <tt>sef</tt> supports.</p>
     *
     * <p>
     * If <tt>sef</tt> is <tt>null</tt>, this method does nothing.</p>
     *
     * @param sef The <tt>StreamElementFactory</tt> to register.
     * @since   JSO-0.10
     */
    public void registerElementFactory(StreamElementFactory sef);
    
    /**
     * <p>
     * Unregisters the given <tt>StreamElementFactory</tt> from the given
     * <tt>NSI</tt>.  This method removes <tt>sef</tt> for <tt>name</tt>, but
     * only if <tt>sef</tt> is currently registered for <tt>name</tt>.</p>
     *
     * <p>
     * If <tt>sef</tt> is <tt>null</tt>, <tt>name</tt> is not supported by
     * <tt>sef</tt>, or <tt>sef</tt> is not registered to <tt>name</tt>, this
     * method does nothing.</p>
     *
     * @param name The <tt>NSI</tt> to unregister from.
     * @param sef The <tt>ExtensionFactory</tt> to unregister.
     * @since   JSO-0.10
     */
    public void unregisterElementFactory(NSI name, StreamElementFactory sef);
    /**
     * <p>
     * Unregisters the given <tt>StreamElementFactory</tt> from all its
     * supported <tt>NSI</tt>s.  This method is designed as a convenience to
     * unregister all of the <tt>NSI</tt>s that an <tt>StreamElementFactory</tt>
     * supports.  This method will not unregister all the namesspaces supported
     * by <tt>sef</tt>, only the <tt>NSI</tt>s supported by and registered to
     * <tt>sef</tt>.</p>
     *
     * <p>
     * If <tt>sef</tt> is <tt>null</tt>, this method does nothing.</p>
     *
     * @param sef The <tt>ExtensionFactory</tt> to unregister.
     * @since   JSO-0.10
     */
    public void unregisterElementFactory(StreamElementFactory sef);
}