/*
 * FeatureConsumerListener.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package org.jabberstudio.jso.event;

/**
 * <p>
 * Interface defined to respond to <tt>FeaturesetConsumerManager</tt>
 * events.</p>
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.12
 */
public interface FeatureConsumerListener {
    //Methods
    /**
     * <p>
     * Method called when a <tt>FeatureConsumer</tt> starts consuming a
     * <tt>StreamFeature</tt>.</p>
     *
     * <p>
     * The value of <tt>evt</tt> should never be <tt>null</tt>.</p>
     *
     * @param evt the <tt>FeatureConsumerEvent</tt> object.
     * @since   JSO-0.12
     */
    public void featureConsumerStarted(FeatureConsumerEvent evt);
    /**
     * <p>
     * Method called when a <tt>FeatureConsumer</tt> fails while consuming a
     * <tt>StreamFeature</tt>.</p>
     *
     * <p>
     * The value of <tt>evt</tt> should never be <tt>null</tt>.</p>
     *
     * @param evt The <tt>FeatureConsumerEvent</tt> object.
     * @since   JSO-0.12
     */
    public void featureConsumerFailed(FeatureConsumerEvent evt);
    /**
     * <p>
     * Method called when a <tt>FeatureConsumer</tt> successfully consumes a
     * <tt>StreamFeature</tt>.</p>
     *
     * <p>
     * The value of <tt>evt</tt> should never be <tt>null</tt>.</p>
     *
     * @param evt The <tt>FeatureConsumerEvent</tt> object.
     * @since   JSO-0.12
     */
    public void featureConsumerSucceeded(FeatureConsumerEvent evt);
}