/*
 * FeatureConsumer.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package org.jabberstudio.jso.features;


import org.jabberstudio.jso.StreamFeature;
import org.jabberstudio.jso.StreamFeatureset;

/**
 * <p>
 * Interface used by <tt>FeaturesetConsumerManager</tt> for consuming a
 * <tt>StreamFeature</tt>.</p>
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.12
 */
public interface FeatureConsumer {
    //Methods
    /**
     * <p>
     * Finds the <tt>StreamFeature</tt> in the given <tt>StreamFeatureset</tt>
     * that can be consumed.</p>
     *
     * <p>
     * The value returned by this method may be <tt>null</tt> if a consumable
     * <tt>StreamFeature</tt> could not be found.</p>
     *
     * <p>
     * The value of <tt>fs</tt> will never be <tt>null</tt>.</p>
     *
     * @param fs The <tt>StreamFeatureset</tt> to search in
     * @return The consumable <tt>StreamFeature</tt>.
     * @since   JSO-0.12
     */
    public StreamFeature findFeature(StreamFeatureset fs);
    /**
     * <p>
     * Consumes the given <tt>FeatureContext</tt>.</p>
     *
     * <p>
     * The value of <tt>ctx</tt> will never be <tt>null</tt>.</p>
     *
     * @param ctx The <tt>FeatureContext</tt> to consume.
     * @throws Exception if there is any error consuming.
     * @since   JSO-0.12
     */
    public void consume(FeatureContext ctx) throws Exception;
    
    /**
     * <p>
     * Resets this <tt>FeatureConsumer</tt>.</p>
     *
     * @since   JSO-0.12
     */
    public void reset();
}