/*
 * OutOfBandExtension.java
 *
 * The contents of this file are subject to the GNU Lesser General Public License
 * Version 2.1 (the "License"). You may not copy or use this file, in either
 * source code or executable form, except in compliance with the License. You
 * may obtain a copy of the License at http://www.fsf.org/licenses/lgpl.txt or
 * http://www.opensource.org/. Software distributed under the License is
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing rights and
 * limitations under the License.
 */

package org.jabberstudio.jso.x.info;


import java.net.URL;

import org.jabberstudio.jso.Extension;
import org.jabberstudio.jso.NSI;

/**
 * <p>
 * Interface for representing "jabber:iq:oob" and "jabber:x:oob" requests, as
 * documented in JEP-0066.</p>
 *
 * @author  linuxwolf
 * @version 0.13-DEV-20050624155226
 * @since   JSO-0.12
 * @see <a href="http://www.jabber.org/jeps/jep-0066.html">JEP-0066: Out of Band Data</a>
 */
public interface OutOfBandExtension extends Extension {
    //"Constants"
    /**
     * The "iq" namespace URI for <tt>OutOfBandExtension</tt> (jabber:iq:oob).
     *
     * @since   JSO-0.12
     */
    public static final String  IQ_NAMESPACE    = "jabber:iq:oob";
    /**
     * The qualified "iq" name for <tt>OutOfBandExtension</tt>
     * ({jabber:iq:oob}query).
     *
     * @since   JSO-0.12
     */
    public static final NSI     IQ_NAME         = new NSI("query", IQ_NAMESPACE);
    
    /**
     * The "x" namespace URI for <tt>OutOfBandExtension</tt> (jabber:x:oob).
     *
     * @since   JSO-0.12
     */
    public static final String  X_NAMESPACE     = "jabber:x:oob";
    /**
     * The qualified "x" name for <tt>OutOfBandExtension</tt>
     * ({jabber:x:oob}query).
     *
     * @since   JSO-0.12
     */
    public static final NSI     X_NAME          = new NSI("x", X_NAMESPACE);
    
    //Methods
    /**
     * <p>
     * Retrieves the URL for this <tt>OutOfBandExtension</tt>.</p>
     *
     * <p>
     * The value returned by this method may be <tt>null</tt> if it has not
     * been set.</p>
     *
     * @return The URL.
     * @since   JSO-0.12
     */
    public URL getURL();
    /**
     * <p>
     * Sets the URL for this <tt>OutOfBandExtension</tt>.</p>
     *
     * <p>
     * The value of <tt>url</tt> may be <tt>null</tt>, in which case the
     * previous value is removed.</p>
     *
     * @param url The new URL.
     * @since   JSO-0.12
     */
    public void setURL(URL url);
    
    /**
     * <p>
     * Retrieves the description for this <tt>OutOfBandExtension</tt>.</p>
     *
     * <p>
     * The value returned by this method is never <tt>null</tt>, but may be
     * "" if it has not been set.</p>
     *
     * @return The description.
     * @since   JSO-0.12
     */
    public String getDescription();
    /**
     * <p>
     * Sets the description for this <tt>OutOfBandExtension</tt>.</p>
     *
     * <p>
     * The value of <tt>desc</tt> may be <tt>null</tt> or "", in which case the
     * previous value is removed.</p>
     *
     * @param desc The new description.
     * @since   JSO-0.12
     */
    public void setDescription(String desc);
}